nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Cfg

Struct Cfg 

#[repr(transparent)]
pub struct Cfg(pub u32);
Configuration for shared functions.

Tuple Fields

0: u32

Implementations

Source

impl Cfg

pub const fn msten(&self) -> bool

Master Enable. When disabled, configurations settings for the Master function are not changed, but the Master function is internally reset.

pub const fn set_msten(&mut self, val: bool)

Master Enable. When disabled, configurations settings for the Master function are not changed, but the Master function is internally reset.

pub const fn slven(&self) -> bool

Slave Enable. When disabled, configurations settings for the Slave function are not changed, but the Slave function is internally reset.

pub const fn set_slven(&mut self, val: bool)

Slave Enable. When disabled, configurations settings for the Slave function are not changed, but the Slave function is internally reset.

pub const fn monen(&self) -> bool

Monitor Enable. When disabled, configurations settings for the Monitor function are not changed, but the Monitor function is internally reset.

pub const fn set_monen(&mut self, val: bool)

Monitor Enable. When disabled, configurations settings for the Monitor function are not changed, but the Monitor function is internally reset.

pub const fn timeouten(&self) -> bool

I2C bus Time-out Enable. When disabled, the time-out function is internally reset.

pub const fn set_timeouten(&mut self, val: bool)

I2C bus Time-out Enable. When disabled, the time-out function is internally reset.

pub const fn monclkstr(&self) -> bool

Monitor function Clock Stretching.

pub const fn set_monclkstr(&mut self, val: bool)

Monitor function Clock Stretching.

pub const fn hscapable(&self) -> Hscapable

High-speed mode Capable enable. Since High Speed mode alters the way I2C pins drive and filter, as well as the timing for certain I2C signalling, enabling High-speed mode applies to all functions: Master, Slave, and Monitor.

pub const fn set_hscapable(&mut self, val: Hscapable)

High-speed mode Capable enable. Since High Speed mode alters the way I2C pins drive and filter, as well as the timing for certain I2C signalling, enabling High-speed mode applies to all functions: Master, Slave, and Monitor.