nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Mstdat

Struct Mstdat 

#[repr(transparent)]
pub struct Mstdat(pub u32);
Combined Master receiver and transmitter data register.

Tuple Fields

0: u32

Implementations

Source

impl Mstdat

pub const fn data(&self) -> u8

Master function data register. Read: read the most recently received data for the Master function. Write: transmit data using the Master function.

pub const fn set_data(&mut self, val: u8)

Master function data register. Read: read the most recently received data for the Master function. Write: transmit data using the Master function.