nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Msttime

Struct Msttime 

#[repr(transparent)]
pub struct Msttime(pub u32);
Master timing configuration.

Tuple Fields

0: u32

Implementations

Source

impl Msttime

pub const fn mstscllow(&self) -> Mstscllow

Master SCL Low time. Specifies the minimum low time that will be asserted by this master on SCL. Other devices on the bus (masters or slaves) could lengthen this time. This corresponds to the parameter t LOW in the I2C bus specification. I2C bus specification parameters tBUF and tSU;STA have the same values and are also controlled by MSTSCLLOW.

pub const fn set_mstscllow(&mut self, val: Mstscllow)

Master SCL Low time. Specifies the minimum low time that will be asserted by this master on SCL. Other devices on the bus (masters or slaves) could lengthen this time. This corresponds to the parameter t LOW in the I2C bus specification. I2C bus specification parameters tBUF and tSU;STA have the same values and are also controlled by MSTSCLLOW.

pub const fn mstsclhigh(&self) -> Mstsclhigh

Master SCL High time. Specifies the minimum high time that will be asserted by this master on SCL. Other masters in a multi-master system could shorten this time. This corresponds to the parameter tHIGH in the I2C bus specification. I2C bus specification parameters tSU;STO and tHD;STA have the same values and are also controlled by MSTSCLHIGH.

pub const fn set_mstsclhigh(&mut self, val: Mstsclhigh)

Master SCL High time. Specifies the minimum high time that will be asserted by this master on SCL. Other masters in a multi-master system could shorten this time. This corresponds to the parameter tHIGH in the I2C bus specification. I2C bus specification parameters tSU;STO and tHD;STA have the same values and are also controlled by MSTSCLHIGH.