nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Slvadr

Struct Slvadr 

#[repr(transparent)]
pub struct Slvadr(pub u32);
Slave address register.

Tuple Fields

0: u32

Implementations

Source

impl Slvadr

pub const fn sadisable(&self) -> Sadisable

Slave Address n Disable.

pub const fn set_sadisable(&mut self, val: Sadisable)

Slave Address n Disable.

pub const fn slvadr(&self) -> u8

Slave Address. Seven bit slave address that is compared to received addresses if enabled.

pub const fn set_slvadr(&mut self, val: u8)

Slave Address. Seven bit slave address that is compared to received addresses if enabled.

pub const fn autonack(&self) -> Autonack

Automatic NACK operation. Used in conjunction with AUTOACK and AUTOMATCHREAD, allows software to ignore I2C traffic while handling previous I2C data or other operations.

pub const fn set_autonack(&mut self, val: Autonack)

Automatic NACK operation. Used in conjunction with AUTOACK and AUTOMATCHREAD, allows software to ignore I2C traffic while handling previous I2C data or other operations.