nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Slvdat

Struct Slvdat 

#[repr(transparent)]
pub struct Slvdat(pub u32);
Combined Slave receiver and transmitter data register.

Tuple Fields

0: u32

Implementations

Source

impl Slvdat

pub const fn data(&self) -> u8

Slave function data register. Read: read the most recently received data for the Slave function. Write: transmit data using the Slave function.

pub const fn set_data(&mut self, val: u8)

Slave function data register. Read: read the most recently received data for the Slave function. Write: transmit data using the Slave function.