nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Slvqual0

Struct Slvqual0 

#[repr(transparent)]
pub struct Slvqual0(pub u32);
Slave Qualification for address 0.

Tuple Fields

0: u32

Implementations

Source

impl Slvqual0

pub const fn qualmode0(&self) -> Qualmode0

Qualify mode for slave address 0.

pub const fn set_qualmode0(&mut self, val: Qualmode0)

Qualify mode for slave address 0.

pub const fn slvqual0(&self) -> u8

Slave address Qualifier for address 0. A value of 0 causes the address in SLVADR0 to be used as-is, assuming that it is enabled. If QUALMODE0 = 0, any bit in this field which is set to 1 will cause an automatic match of the corresponding bit of the received address when it is compared to the SLVADR0 register. If QUALMODE0 = 1, an address range is matched for address 0. This range extends from the value defined by SLVADR0 to the address defined by SLVQUAL0 (address matches when SLVADR0[7:1] <= received address <= SLVQUAL0[7:1]).

pub const fn set_slvqual0(&mut self, val: u8)

Slave address Qualifier for address 0. A value of 0 causes the address in SLVADR0 to be used as-is, assuming that it is enabled. If QUALMODE0 = 0, any bit in this field which is set to 1 will cause an automatic match of the corresponding bit of the received address when it is compared to the SLVADR0 register. If QUALMODE0 = 1, an address range is matched for address 0. This range extends from the value defined by SLVADR0 to the address defined by SLVQUAL0 (address matches when SLVADR0[7:1] <= received address <= SLVQUAL0[7:1]).