#[repr(transparent)]pub struct Slvadr(pub u32);Expand description
Slave address register.
Tuple Fields
0: u32Implementations
Sourceimpl Slvadr
impl Slvadr
Sourcepub const fn set_sadisable(&mut self, val: Sadisable)
pub const fn set_sadisable(&mut self, val: Sadisable)
Slave Address n Disable.
Sourcepub const fn slvadr(&self) -> u8
pub const fn slvadr(&self) -> u8
Slave Address. Seven bit slave address that is compared to received addresses if enabled.
Sourcepub const fn set_slvadr(&mut self, val: u8)
pub const fn set_slvadr(&mut self, val: u8)
Slave Address. Seven bit slave address that is compared to received addresses if enabled.
Sourcepub const fn autonack(&self) -> Autonack
pub const fn autonack(&self) -> Autonack
Automatic NACK operation. Used in conjunction with AUTOACK and AUTOMATCHREAD, allows software to ignore I2C traffic while handling previous I2C data or other operations.
Sourcepub const fn set_autonack(&mut self, val: Autonack)
pub const fn set_autonack(&mut self, val: Autonack)
Automatic NACK operation. Used in conjunction with AUTOACK and AUTOMATCHREAD, allows software to ignore I2C traffic while handling previous I2C data or other operations.